import pandas as pd
from sklearn.feature_extraction.text import CountVectorizer
from sklearn.model_selection import train_test_split
from sklearn.linear_model import LogisticRegression
from sklearn import metrics
import matplotlib.pyplot as pp
import scikitplot as skplt

# loads test dataframe

print("Reading test data")

test_df = pd.read_csv("./stock_data_semicol.csv", delimiter=";")

# loads sharp data

print("Reading sharp data")

agri_df = pd.read_csv("../dp_data/cutted-data.csv", delimiter=",")


def vectorize(df, label, col):
    print("Starting vectorize data frame" + " : " + label)

    vectorizer = CountVectorizer(stop_words="english", max_features=9000)

    vec = vectorizer.fit_transform(df[col])

    print("Creating vectorized data frame from df" + " : " + label)

    return pd.DataFrame(vec.toarray()) 


# vectorize test data frame

vec_test_df = vectorize(test_df, "test", "Text")


# vectorize sharp data

vec_sharp_df = vectorize(agri_df, "sharp", "fulltext")

# split testing data to training and testing sets

print("Splitting sets to train and test in ratio 80:20")

x_train, x_test, y_train, y_test = train_test_split(vec_test_df, test_df["Sentiment"], test_size=0.2, random_state=200)


# create Model

logreg = LogisticRegression()

print("Training model on train sets")

logreg.fit(x_train, y_train)

# display model score

model_score = logreg.score(x_test, y_test)

print("Score is :" + str(model_score))

# Confusion matrix

test_prediction = logreg.predict(x_test)

test_prediction_proba = logreg.predict_proba(x_test)

cof_matrix = metrics.confusion_matrix(y_test,test_prediction)

print("Confusion matrix of test model")

print(cof_matrix)

# Evaluating agri data

print("Predicting sharp data")

prediction = logreg.predict(vec_sharp_df)

prediction_df = pd.DataFrame(prediction, columns=["Sentiment"])

#cof_matrix_display = metrics.ConfusionMatrixDisplay(cof_matrix)

#cof_matrix_display.plot()

#skplt.metrics.plot_ks_statistic(y_test, test_prediction_proba)

#skplt.metrics.plot_cumulative_gain(y_test, test_prediction_proba)

#skplt.metrics.plot_lift_curve(y_test, test_prediction_proba)

#skplt.metrics.plot_roc(y_test, test_prediction_proba)

#pp.show()

